@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # Copyright (c) 2017 David Steele <dsteele@gmail.com>
 #
 # SPDX-License-Identifier: GPL-2+
@@ -24,10 +24,12 @@ sys.path.append('..')
 
 from comitup import client as ciu                 # noqa
 
+ciu_client = None
+
 
 def do_connect(ssid, password):
     time.sleep(1)
-    ciu.ciu_connect(ssid, password)
+    ciu_client.ciu_connect(ssid, password)
 
 
 def create_app():
@@ -35,7 +37,7 @@ def create_app():
 
     @app.route("/")
     def index():
-        points = ciu.ciu_points()
+        points = ciu_client.ciu_points()
         for point in points:
             point['ssid_encoded'] = urllib.parse.quote(point['ssid'])
         return render_template("index.html", points=points)
@@ -46,11 +48,15 @@ def create_app():
         ssid = request.args.get("ssid", "")
         ssid_encoded = urllib.parse.quote(ssid.encode())
         encrypted = request.args.get("encrypted", "unencrypted")
+
+        mode = ciu_client.ciu_info()['imode']
+
         return render_template(
                                 "confirm.html",
                                 ssid=ssid,
                                 encrypted=encrypted,
                                 ssid_encoded=ssid_encoded,
+                                mode=mode,
                                 )
 
 
@@ -65,12 +71,15 @@ def create_app():
         return render_template("connect.html",
                                 ssid=ssid,
                                 password=password,
-                            )
+                              )
 
     return app
 
 
 def main():
+    global ciu_client
+    ciu_client = ciu.CiuClient()
+
     app = create_app()
     app.run(host="0.0.0.0", port=80, debug=True, threaded=True)
 
